#!/usr/bin/perl -w

package MT::Plugin::YandexOpenId;

use MT;
use strict;
use base qw( MT::Plugin );
our $VERSION = '1.0';

require MT::Auth::Yandex;

my $plugin = MT::Plugin::YandexOpenId->new({
    key         => 'YandexId',
    id          => 'YandexId',
    name        => 'Яндекс.OpenID',
    description => "Авторизация комментаторов через Яндекс.",
    version     => $VERSION,
    author_name => "Andrey Serebryakov",
    author_link => "http://blogstudio.ru/",
    plugin_link => "http://code.google.com/p/mt-plugins/wiki/YandexOpenId",
});

sub instance { $plugin; }

MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        commenter_authenticators => {
            'Yandex' => {
                class => 'MT::Auth::Yandex',
                label => 'Yandex',
                login_form_params => \&_commenter_auth_params,
                condition => \&_openid_commenter_condition,
                logo => 'plugins/YandexOpenId/images/yandex.png',
                login_form => <<YANDEX,
<form method="post" action="<mt:var name="script_url">">
<input type="hidden" name="__mode" value="login_external" />
<input type="hidden" name="blog_id" value="<mt:var name="blog_id">" />
<input type="hidden" name="entry_id" value="<mt:var name="entry_id">" />
<input type="hidden" name="static" value="<mt:var name="static" escape="html">" />
<input type="hidden" name="key" value="Yandex" />
<fieldset>
<mtapp:setting
    id="yandex_display"
    label="Ваш логин на Яндексе">
<input name="openid_userid" style="background: #fff 
    url('<mt:var name="static_uri">plugins/YandexOpenId/images/yandex_logo.png') 
no-repeat left; padding-left: 18px; padding-bottom: 1px; 
border: 1px solid #5694b6; width: 304px; font-size: 110%;" />
<p class="hint">Авторизуйтесь с помощью Яндекса</p>
</mtapp:setting>
<img src="<mt:var name="static_uri">plugins/YandexOpenId/images/yandex-openid.gif" class="right" />
<div class="actions-bar actions-bar-login">
    <div class="actions-bar-inner pkg actions">
    <button type="submit" class="primary-button">Авторизоваться</button>
    </div>
</div>
<p><img src="<mt:var name="static_uri">images/comment/blue_moreinfo.png"> <a href="http://openid.yandex.ru/">Узнать больше о Яндекс.OpenID.</a> </p>
</fieldset>
</form>
YANDEX
            },
        },
    });
}

sub _commenter_auth_params {
    my ( $key, $blog_id, $entry_id, $static ) = @_;
    my $params = {
        blog_id => $blog_id,
        static  => $static,
    };
    $params->{entry_id} = $entry_id if defined $entry_id;
    return $params;
}

sub _openid_commenter_condition {
    eval "require Digest::SHA1;";
    return $@ ? 0 : 1;
}

1;
__END__

